#[non_exhaustive]pub enum DiscoveryError {
InvalidIssuerUrl(ParseError),
Http(HttpError),
Status(u16),
Parse(Error),
IssuerMismatch,
}Expand description
A failure while fetching OpenID Connect provider metadata from a
.well-known/openid-configuration document.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidIssuerUrl(ParseError)
The issuer URL could not be turned into a discovery URL.
Http(HttpError)
The metadata request failed at the transport layer.
Status(u16)
The discovery endpoint returned a non-2xx status.
Parse(Error)
The metadata document could not be deserialized.
IssuerMismatch
The issuer in the metadata did not match the requested issuer URL
(OpenID Connect Discovery 4.3) — a misconfigured or hostile provider.